SourceParseMetadata

Struct SourceParseMetadata 

pub struct SourceParseMetadata {
    pub path: String,
    pub language: Option<String>,
    pub parser: ParserKind,
    pub symbol_count: usize,
    pub relation_count: usize,
}
File-level parser metadata persisted even when a graph has no symbols.

Fields

path: String

Repository-relative file path.

language: Option<String>

Detected language or file family.

parser: ParserKind

Primary parser strategy used for the file.

symbol_count: usize

Number of declaration or manifest symbols emitted for this file.

relation_count: usize

Number of relations emitted for this file.

Implementations

Source

impl SourceParseMetadata

pub fn from_graph(graph: &SymbolGraph) -> Self

Build persisted parser metadata from a graph.