pub struct SourceParseMetadata {
pub path: String,
pub language: Option<String>,
pub parser: ParserKind,
pub symbol_count: usize,
pub relation_count: usize,
}Expand description
File-level parser metadata persisted even when a graph has no symbols.
Fields
path: StringRepository-relative file path.
language: Option<String>Detected language or file family.
parser: ParserKindPrimary parser strategy used for the file.
symbol_count: usizeNumber of declaration or manifest symbols emitted for this file.
relation_count: usizeNumber of relations emitted for this file.
Implementations
Sourceimpl SourceParseMetadata
impl SourceParseMetadata
Sourcepub fn from_graph(graph: &SymbolGraph) -> Self
pub fn from_graph(graph: &SymbolGraph) -> Self
Build persisted parser metadata from a graph.